# What does _**poodio**_ do?

💩 💨 Farts poo poo audio 💨 💩

[![Npmjs.com](https://img.shields.io/npm/v/poodio?style=for-the-badge&label=NPMJS&logo=npm&logoColor=%23c33&labelColor=%23333&color=%23c33)](https://www.npmjs.com/package/poodio)
[![Crates.io](https://img.shields.io/crates/v/poodio?style=for-the-badge&label=CRATES&logo=docs.rs&logoColor=%23fc3&labelColor=%23333&color=%23fc3)](https://docs.rs/poodio)
[![License](https://img.shields.io/crates/l/poodio?style=for-the-badge&label=LICENSE&logo=opensourceinitiative&logoColor=%23fff&labelColor=%23333&color=%234a3)](https://docs.rs/crate/poodio/latest/source/LICENSE.txt)
[![PyPI.org](https://img.shields.io/pypi/v/poodio?style=for-the-badge&label=PYPI&logo=pypi&logoColor=%23fc4&labelColor=%23333&color=%2337a)](https://pypi.org/project/poodio/)
[![Issues](https://img.shields.io/github/issues/AsherJingkongChen/poopoo?style=for-the-badge&label=ISSUES&logo=github&logoColor=%23fff&labelColor=%23333&color=%23eee)](https://github.com/AsherJingkongChen/poopoo/issues)

## Install & Run

💩 We provide several ways to install and run **`poodio`** on your system with a single command. 💩

| 💩 Method 💩                                        | 💩 Command 💩                                                                           |
| --------------------------------------------------- | --------------------------------------------------------------------------------------- |
| 1. [`bunx`](https://bun.sh/)                        | <ul><li>`bunx poodio`</li><li>`bunx --bun poodio`</li><li>`bunx poodio@0.1.0`</li></ul> |
| 2. [`npx`](https://nodejs.org/en/download/)         | <ul><li>`npx -y poodio`</li><li>`npx -y poodio@0.1.0`</li></ul>                         |
| 3. [`pipx`](https://pypi.org/project/pipx/)         | <ul><li>`pipx run poodio`</li><li>`pipx run poodio==0.1.0`</li></ul>                    |
| 4. [`uvx`](https://docs.astral.sh/uv/#installation) | <ul><li>`uvx poodio`</li><li>`uvx poodio==0.1.0`</li></ul>                              |

## Install

💩 We provide several ways to install **`poodio`** so you can [run](#run) it later. 💩

| 💩 Method 💩                                                                                                             | 💩 Command 💩                                                                                                                                                                                                                                                         |
| ------------------------------------------------------------------------------------------------------------------------ | --------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| 1. [`cargo-binstall`](https://github.com/cargo-bins/cargo-binstall?tab=readme-ov-file#installation)                      | <ul><li>`cargo-binstall -y poodio`</li><li>`cargo-binstall -y poodio@0.1.0`</li></ul>                                                                                                                                                                                 |
| 2. [`npm`](https://nodejs.org/en/download/)                                                                              | <ul><li>`npm i -g poodio`</li><li>`npm i -g poodio@0.1.0` </li></ul>                                                                                                                                                                                                  |
| 3. [`pip`](https://pip.pypa.io/en/stable/installation/)                                                                  | <ul><li>`pip install poodio`</li><li>`pip install poodio==0.1.0`</li></ul>                                                                                                                                                                                            |
| 4. [`uv`](https://docs.astral.sh/uv/#installation)                                                                       | <ul><li>`uv tool install poodio`</li><li>`uv tool install poodio==0.1.0`</li></ul>                                                                                                                                                                                    |
| 5. [`git`](https://git-scm.com/downloads) & [`cargo`](https://doc.rust-lang.org/cargo/getting-started/installation.html) | <ul><li>`git clone https://github.com/AsherJingkongChen/poopoo -b main --depth 1`<br>`cargo install --path poopoo/poodio`</li><li>`git clone https://github.com/AsherJingkongChen/poopoo -b poodio@0.1.0 --depth 1`<br>`cargo install --path poopoo/poodio`</li></ul> |

## Run

💩 After [installing](#install), run **`poodio`** with the following commands. 💩

| 💩 Action 💩              | 💩 Command 💩                                            |
| ------------------------- | -------------------------------------------------------- |
| 💩 Prints help info 💩    | <ul><li>`poodio -h`</li><li>`poodio --help`</li></ul>    |
| 💩 Prints version info 💩 | <ul><li>`poodio -V`</li><li>`poodio --version`</li></ul> |

## Integrate

💩 You can integrate **`poodio`** into your own project with the following commands. 💩

| 💩 Method 💩                                                                                                             | 💩 Command 💩                                                                                                                                                                                                                                                 |
| ------------------------------------------------------------------------------------------------------------------------ | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| 1. [`cargo`](https://doc.rust-lang.org/cargo/getting-started/installation.html)                                          | <ul><li>`cargo add poodio`</li><li>`cargo add poodio@0.1.0`</li></ul>                                                                                                                                                                                         |
| 2. [`npm`](https://nodejs.org/en/download/)                                                                              | <ul><li>`npm i poodio`</li><li>`npm i poodio@0.1.0` </li></ul>                                                                                                                                                                                                |
| 3. [`uv`](https://docs.astral.sh/uv/#installation)                                                                       | <ul><li>`uv add poodio`</li><li>`uv add poodio==0.1.0`</li></ul>                                                                                                                                                                                              |
| 4. [`git`](https://git-scm.com/downloads) & [`cargo`](https://doc.rust-lang.org/cargo/getting-started/installation.html) | <ul><li>`git clone https://github.com/AsherJingkongChen/poopoo -b main --depth 1`<br>`cargo add --path poopoo/poodio`</li><li>`git clone https://github.com/AsherJingkongChen/poopoo -b poodio@0.1.0 --depth 1`<br>`cargo add --path poopoo/poodio`</li></ul> |
